.. include:: ../README.rst

Table of Contents
=================

.. toctree::
    :maxdepth: 4
    :hidden:

    self

.. toctree::
    :caption: Examples

    examples

.. toctree::
    :caption: API Reference
    :maxdepth: 3

    api

.. toctree::
    :caption: Tutorials

    1.8" TFT Display Breakout and Shield <https://learn.adafruit.com/1-8-tft-display>
    Adafruit Mini TFT - 0.96" 160x80 <https://learn.adafruit.com/adafruit-mini-tft-0-dot-96-inch-180x60-breakout>
    Adafruit Mini TFT with Joystick Featherwing <https://learn.adafruit.com/adafruit-mini-tft-featherwing>

.. toctree::
    :caption: Related Products

    1.8" SPI TFT display, 160x128 18-bit color <https://www.adafruit.com/product/618>
    Adafruit 0.96" 160x80 Color TFT Display w/ MicroSD Card Breakout <https://www.adafruit.com/product/3533>
    1.8" Color TFT LCD display with MicroSD Card Breakout <https://www.adafruit.com/product/358>
    Adafruit 1.44" Color TFT LCD Display with MicroSD Card breakout <https://www.adafruit.com/product/2088>
    Adafruit Mini Color TFT with Joystick FeatherWing <https://www.adafruit.com/product/3321>

.. toctree::
    :caption: Other Links

    Download from GitHub <https://github.com/adafruit/adafruit_CircuitPython_ST7735R/releases/latest>
    Download Library Bundle <https://circuitpython.org/libraries>
    CircuitPython Reference Documentation <https://docs.circuitpython.org>
    CircuitPython Support Forum <https://forums.adafruit.com/viewforum.php?f=60>
    Discord Chat <https://adafru.it/discord>
    Adafruit Learning System <https://learn.adafruit.com>
    Adafruit Blog <https://blog.adafruit.com>
    Adafruit Store <https://www.adafruit.com>

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
